@@ -1,6 +1,4 @@
 #!perl
-use Modern::Perl;
-
 package Mineral;
 use Moose;
 
@@ -25,6 +23,6 @@ my 	$paco = build_instance(
 	);
 
 does_ok( $paco, 'Identity', 'Check that the ' . $paco->meta->name . ' has an -Identity-' );
-say 'My ' . $paco->meta->name . ' made from -' . $paco->type . '- (a ' .
-( join ', ', $paco->meta->superclasses ) . ') is called -' . $paco->name . '-';
+print'My ' . $paco->meta->name . ' made from -' . $paco->type . '- (a ' .
+( join ', ', $paco->meta->superclasses ) . ') is called -' . $paco->name . "-\n";
 done_testing();
\ No newline at end of file
